Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(239)

Unified Diff: chrome/browser/chromeos/gdata/gdata_uploader.h

Issue 10828385: Rename DocumentsServiceInterface to DriveServiceInterface. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase. Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/gdata/gdata_uploader.h
diff --git a/chrome/browser/chromeos/gdata/gdata_uploader.h b/chrome/browser/chromeos/gdata/gdata_uploader.h
index 1b0e583d99774f035ad26f72233e3b9051cca6ba..941d23ebc2d7eaef16e2cec359bb5fa0c0b54e98 100644
--- a/chrome/browser/chromeos/gdata/gdata_uploader.h
+++ b/chrome/browser/chromeos/gdata/gdata_uploader.h
@@ -23,7 +23,7 @@ class DownloadItem;
namespace gdata {
-class DocumentsServiceInterface;
+class DriveServiceInterface;
class GDataUploaderInterface {
public:
@@ -59,7 +59,7 @@ class GDataUploaderInterface {
class GDataUploader : public GDataUploaderInterface {
public:
- explicit GDataUploader(DocumentsServiceInterface* documents_service);
+ explicit GDataUploader(DriveServiceInterface* drive_service);
virtual ~GDataUploader();
// GDataUploaderInterface overrides.
@@ -87,7 +87,7 @@ class GDataUploader : public GDataUploaderInterface {
// open operation is passed as |result|.
void OpenCompletionCallback(int upload_id, int result);
// DocumentsService callback for InitiateUpload.
void OnUploadLocationReceived(int upload_id,
GDataErrorCode code,
const GURL& upload_location);
@@ -100,10 +100,10 @@ class GDataUploader : public GDataUploaderInterface {
int bytes_to_read,
int bytes_read);
// Calls DocumentsService's ResumeUpload with the current upload info.
void ResumeUpload(int upload_id);
// DocumentsService callback for ResumeUpload.
void OnResumeUploadResponseReceived(int upload_id,
const ResumeUploadResponse& response,
scoped_ptr<DocumentEntry> entry);
@@ -124,10 +124,10 @@ class GDataUploader : public GDataUploaderInterface {
// ID assigned to |upload_file_info|.
int StartUploadFile(scoped_ptr<UploadFileInfo> upload_file_info);
// Pointers to DocumentsServiceInterface object owned by GDataSystemService.
// The lifetime of this object is guaranteed to exceed that of the
// GDataUploader instance.
- DocumentsServiceInterface* documents_service_;
+ DriveServiceInterface* drive_service_;
int next_upload_id_; // id counter.

Powered by Google App Engine
@@ -87,7 +87,7 @@ class GDataUploader : public GDataUploaderInterface {
// open operation is passed as |result|.
void OpenCompletionCallback(int upload_id, int result);
- // DocumentsService callback for InitiateUpload.
+ // DriveService callback for InitiateUpload.
void OnUploadLocationReceived(int upload_id,
GDataErrorCode code,
@@ -100,10 +100,10 @@ class GDataUploader : public GDataUploaderInterface {
int bytes_to_read,
int bytes_read);
- // Calls DocumentsService's ResumeUpload with the current upload info.
+ // Calls DriveService's ResumeUpload with the current upload info.
void ResumeUpload(int upload_id);
@@ -100,10 +100,10 @@ class GDataUploader : public GDataUploaderInterface {
void ResumeUpload(int upload_id);
- // DocumentsService callback for ResumeUpload.
+ // DriveService callback for ResumeUpload.
void OnResumeUploadResponseReceived(int upload_id,
const ResumeUploadResponse& response,
@@ -124,10 +124,10 @@ class GDataUploader : public GDataUploaderInterface {
// ID assigned to |upload_file_info|.
int StartUploadFile(scoped_ptr<UploadFileInfo> upload_file_info);
- // Pointers to DocumentsServiceInterface object owned by GDataSystemService.
+ // Pointers to DriveServiceInterface object owned by GDataSystemService.
// The lifetime of this object is guaranteed to exceed that of the
// GDataUploader instance.
This is Rietveld 408576698